@@ -242,7 +242,7 @@ winimg_len(imglist *img)
 
 bool
 winimg_new(imglist **ppimg, char * id, unsigned char * pixels, uint len,
-           int left, int top, int width, int height,
+           int left, int scrtop, int width, int height,
            int pixelwidth, int pixelheight, bool preserveAR,
            int crop_x, int crop_y, int crop_width, int crop_height,
            int attr)
@@ -259,13 +259,13 @@ winimg_new(imglist **ppimg, char * id, unsigned char * pixels, uint len,
 #ifdef debug_img_disp
   printf("winimg_new %d @%d:%d\n", _imgi, left, top);
 #endif
-  img->imgi = _imgi++;
+  img->imgi = ++_imgi;
 
   img->pixels = pixels;
   img->hdc = NULL;
   img->hbmp = NULL;
   img->left = left;
-  img->top = top;
+  img->top = term.virtuallines + scrtop;
   img->width = width;
   img->height = height;
   img->pixelwidth = pixelwidth;
@@ -741,7 +741,7 @@ winimgs_paint(void)
               printf("paint: dirty (%d) %d:%d %d >= %d\n", disp_flag, y, x, img->imgi, dchar->attr.imgi);
 #endif
             }
-            // if cell is overlaid by selection or cursor, exclude
+            // if cell is overlaid by selection or cursor, exclude it.
             if (dchar->attr.attr & (TATTR_RESULT | TATTR_CURRESULT | TATTR_MARKED | TATTR_CURMARKED))
               clip_flag = true;
             if (term.selected && !clip_flag) {
@@ -909,7 +909,7 @@ winimgs_paint(void)
 #include "charset.h"  // path_win_w_to_posix
 
 void
-win_emoji_show(int x, int y, wchar * efn, void * * bufpoi, int * buflen, int elen, ushort lattr)
+win_emoji_show(int x, int y, wchar * efn, void * * bufpoi, int * buflen, int elen, ushort lattr, bool italic)
 {
   gdiplus_init();
 
@@ -1006,6 +1006,26 @@ win_emoji_show(int x, int y, wchar * efn, void * * bufpoi, int * buflen, int ele
   }
 
   HDC dc = GetDC(wnd);
+
+  int coord_transformed = 0;
+  XFORM old_xform;
+  coord_transformed = italic && SetGraphicsMode(dc, GM_ADVANCED);
+  if (coord_transformed && GetWorldTransform(dc, &old_xform)) {
+    //XFORM xform = (XFORM){1.0, 0.0, 1.1, 1.0, -1.1, 0.0};
+    /* {eM11, eM12, eM21, eM22, eDx, eDy}
+       y' = x * eM12 + y * eM22 + eDy
+       x' = x * eM11 + y * eM21 + eDx
+       x' = x + ( (r+h-1-y) / h) * w/4 - bottom-line_x-undent(w/8)
+     */
+    XFORM xform = (XFORM){1.0, 0.0, 0.0, 1.0, 0.0, 0.0};
+    xform.eM21 = ((float)cell_width) * -0.25 / ((float)cell_height);
+    //xform.eDx = ((float)cell_width) * 0.25 * ((float)(row - 1) / ((float)cell_height) + 1.0)
+    //          - ((float)cell_width) * 0.125;
+    xform.eDx = ((float)cell_width) * 
+             (0.25 * ((float)(row - 1) / ((float)cell_height) + 1.0) - 0.125);
+    coord_transformed = SetWorldTransform(dc, &xform);
+  }
+
   GpGraphics * gr;
   s = GdipCreateFromHDC(dc, &gr);
   gpcheck("hdc", s);
@@ -1020,6 +1040,9 @@ win_emoji_show(int x, int y, wchar * efn, void * * bufpoi, int * buflen, int ele
   s = GdipDisposeImage(img);
   gpcheck("dispose img", s);
 
+  if (coord_transformed)
+    SetWorldTransform(dc, &old_xform);
+
   ReleaseDC(wnd, dc);
 
   if (fs) {
@@ -1072,11 +1095,11 @@ save_img(HDC dc, int x, int y, int w, int h, wstring fn)
 #else
 
 void
-win_emoji_show(int x, int y, wchar * efn, void * * bufpoi, int * buflen, int elen, ushort lattr)
+win_emoji_show(int x, int y, wchar * efn, void * * bufpoi, int * buflen, int elen, ushort lattr, bool italic)
 {
   (void)x; (void)y;
   (void)efn; (void)bufpoi; (void)buflen;
-  (void)elen; (void)lattr;
+  (void)elen; (void)lattr; (void)italic;
 }
 
 void
